#if defined __in_droppedammo_stock
  #endinput
#endif
#define __in_droppedammo_stock

/**
 * Gets the reserved ammo of a dropped weapon.
 *
 * @param weapon		Weapon index.
 * 
 * @return              Reserved ammo for that weapon
 * @error				Weapon is not dropped, gamedata issues or offset not found.
 */
stock CS_GetDroppedWeaponAmmo(weapon)
{
	static String:startprop[64];
	static offset = -1;
	
	if (GetEntPropEnt(weapon, Prop_Send, "m_hOwnerEntity") != -1)
		ThrowError("Weapon is not dropped");
	
	if (startprop[0] == '\0' || offset == -1)
	{
		new Handle:conf = LoadGameConfigFile("cssdroppedammo");
		if (conf == INVALID_HANDLE)
			ThrowError("Cannot find gamedata/cssdroppedammo.txt");
		
		if (!GameConfGetKeyValue(conf, "DroppedAmmoStart", startprop, sizeof(startprop))
			|| (offset = GameConfGetOffset(conf, "DroppedAmmoStartOffset")) == -1)
		{
			CloseHandle(conf);
			ThrowError("Could not find either DroppedAmmoStart or DroppedAmmoStartOffset in gamedata file");
		}
		
		CloseHandle(conf);
		
		new start = FindSendPropInfo("CWeaponCSBase", startprop);
		if (start == -1)
			ThrowError("Could not find netprop \"%s\" on CWeaponCSBase", startprop);
		
		offset += start;
	}
	
	return GetEntData(weapon, offset);
}

/**
 * Sets the reserved ammo of a dropped weapon.
 *
 * @param weapon		Weapon index.
 * @param ammo  		Amount of ammunition to set to.
 * 
 * @return              Reserved ammo for that weapon
 * @error				Weapon is not dropped, gamedata issues or offset not found.
 */
stock CS_SetDroppedWeaponAmmo(weapon, ammo)
{
	static String:startprop[64];
	static offset = -1;
	
	if (GetEntPropEnt(weapon, Prop_Send, "m_hOwnerEntity") != -1)
		ThrowError("Weapon is not dropped");
	
	if (startprop[0] == '\0' || offset == -1)
	{
		new Handle:conf = LoadGameConfigFile("cssdroppedammo");
		if (conf == INVALID_HANDLE)
			ThrowError("Cannot find gamedata/cssdroppedammo.txt");
		
		if (!GameConfGetKeyValue(conf, "DroppedAmmoStart", startprop, sizeof(startprop))
			|| (offset = GameConfGetOffset(conf, "DroppedAmmoStartOffset")) == -1)
		{
			CloseHandle(conf);
			ThrowError("Could not find either DroppedAmmoStart or DroppedAmmoStartOffset in gamedata file");
		}
		
		CloseHandle(conf);
		
		new start = FindSendPropInfo("CWeaponCSBase", startprop);
		if (start == -1)
			ThrowError("Could not find netprop \"%s\" on CWeaponCSBase", startprop);
		
		offset += start;
	}
	
	SetEntData(weapon, offset, ammo);
}